# Automanage

> see https://aka.ms/autorest

This is the AutoRest configuration file for Automanage.

---

## Getting Started

To build the SDK for Automanage, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the Automanage API.

``` yaml
title: AutomanageClient
description: Automanage Client
openapi-type: arm
tag: package-2021-04-30-preview
```

### Tag: package-2021-04-30-preview

These settings apply only when `--tag=package-2021-04-30-preview` is specified on the command line.

``` yaml $(tag) == 'package-2021-04-30-preview'
input-file:
- Microsoft.Automanage/preview/2021-04-30-preview/automanage.json
directive:
  - suppress: R3010
    from: Microsoft.Automanage/preview/2021-04-30-preview/automanage.json
    reason: list by immediate parent operations are defined
```

### Tag: package-2020-06-30-preview

These settings apply only when `--tag=package-2020-06-30-preview` is specified on the command line.

``` yaml $(tag) == 'package-2020-06-30-preview'
input-file:
- Microsoft.Automanage/preview/2020-06-30-preview/automanage.json
```

## Suppression

``` yaml
directive:
  - suppress: UniqueResourcePaths
    from: automanage.json
    where: $.paths
    reason: 'Microsoft.Automanage is a proxy resource provider under Microsoft. Please refer PR https://github.com/Azure/azure-rest-api-specs-pr/pull/1283'
  - suppress: R3018  # EnumInsteadOfBoolean - Booleans are not descriptive and make them hard to use. Consider using string enums with allowed set of values defined. Property: isDataAction"
    where:
      - $.definitions.Operation.properties.isDataAction
    from: types.json
    reason: its per the RPC specification
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-go-track2
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_automanage']
  - repo: azure-powershell
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.Automanage
  output-folder: $(csharp-sdks-folder)/automanage/Microsoft.Azure.Management.Automanage/src/Generated
  clear-output-folder: true
```

