# CloudShell

> see https://aka.ms/autorest

This is the AutoRest configuration file for CloudShell.

## Getting Started

To build the SDKs for CloudShell, simply install AutoRest via `npm` (`npm install -g autorest`) and then run:

> `autorest readme.md`

To see additional help and options, run:

> `autorest --help`

For other options on installation see [Installing AutoRest](https://aka.ms/autorest/install) on the AutoRest github page.

---

## Configuration

### Basic Information

These are the global settings for the CloudShell.

```yaml
openapi-type: arm
tag: package-2018-10-01
```

### Tag: package-2018-10-01

These settings apply only when `--tag=package-2018-10-01` is specified on the command line.

```yaml $(tag) == 'package-2018-10-01'
input-file:
  - Microsoft.Portal/stable/2018-10-01/CloudShell.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

```yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_cloudshell']
  - repo: azure-resource-manager-schemas
  - repo: azure-powershell
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  clear-output-folder: true
  namespace: cloudshell
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.

``` yaml $(python)
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: Microsoft.Portal
  package-name: CloudShell
  clear-output-folder: true
```
``` yaml $(python)
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt/cloudshell
```

## Ruby

```yaml
package-name: azure_mgmt_cloudshell
package-version: 2018-10-01
azure-arm: true
```

### Tag: package-2018-10-01 and ruby

These settings apply only when `--tag=package-2018-10-01 --ruby` is specified on the command line.
Please also specify `--ruby-sdks-folder=<path to the root directory of your azure-sdk-for-ruby clone>`.

```yaml $(tag) == 'package-2018-10-01' && $(ruby)
namespace: Microsoft.Portal
output-folder: $(ruby-sdks-folder)/CloudShell
```

### Tag: package-2020-04-01 and ruby

These settings apply only when `--tag=package-2018-04-01 --ruby` is specified on the command line.
Please also specify `--ruby-sdks-folder=<path to the root directory of your azure-sdk-for-ruby clone>`.

```yaml $(tag) == 'package-2018-04-01' && $(ruby)
namespace: Microsoft.Portal
output-folder: $(ruby-sdks-folder)/CloudShell
```

## TypeScript

These settings apply only when `--typescript` is specified on the command line.
Please also specify `--typescript-sdks-folder=<path to root folder of your azure-sdk-for-js clone>`.

```yaml $(typescript)
typescript:
  azure-arm: true
  package-name: "CloudShell"
  output-folder: "$(typescript-sdks-folder)/packages/CloudShell"
  payload-flattening-threshold: 1
  generate-metadata: true
```

## CSharp

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

```yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 1
  clear-output-folder: true
  client-side-validation: false
  namespace: Microsoft.CloudShell
  output-folder: $(csharp-sdks-folder)/CloudShell/management/Microsoft.CloudShell/GeneratedProtocol
```


